mistune: A markdown parser in pure Python
=========================================

Description
-----------

The fastest markdown parser in pure Python

License
-------

BSD License


Upstream Contact
----------------

Home Page: https://github.com/lepture/mistune

Dependencies
------------

Python, Cython, Pip
